package de.starzi.graphics.textures;

import org.lwjgl.opengl.GL11;
import org.lwjgl.opengl.GL13;
import org.lwjgl.opengl.GL20;

import de.starzi.graphics.opengl.GLError;

public class ImageUnit {
	
	public static final int IMAGE_UNIT_COUNT = GL11.glGetInteger(GL13.GL_MAX_TEXTURE_UNITS);
	public static final int COMBINED_IMAGE_UNIT_COUNT = GL11.glGetInteger(GL20.GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS);
	public static final int TEXTURE_COORDS_COUNT = GL11.glGetInteger(GL20.GL_MAX_TEXTURE_COORDS);
	private static final int ID0 = GL13.GL_TEXTURE0;
	
	private static final ImageUnit[] TEXTURE_UNITS = new ImageUnit[IMAGE_UNIT_COUNT];
	static {
		for (int i = 0; i < TEXTURE_UNITS.length; i++) {
			TEXTURE_UNITS[i] = new ImageUnit(ID0 + i);
		}
	}
	
	private static ImageUnit active = TEXTURE_UNITS[0];
	private static ImageUnit activeClient = TEXTURE_UNITS[0];
	
	public static ImageUnit get_active() {
		return active;
	}
	
	public static ImageUnit get_active_clientArray() {
		return activeClient;
	}
	
	public static boolean available(int i) {
		return i >= 0 && i < TEXTURE_UNITS.length;
	}
	
	public static ImageUnit get(int i) {
		return TEXTURE_UNITS[i];
	}
	
	private final int id;
	
	private ImageUnit(int id) {
		this.id = id;
	}
	
	public void activate() {
		GL13.glActiveTexture(id);
		GLError.throwIfNecessary(this, "glActiveTexture");
		active = this;
	}
	
	public boolean is_active() {
		return active == this;
	}
	
	public boolean supports_clientArray() {
		return id < TEXTURE_COORDS_COUNT;
	}
	
	public void activate_clientArray() {
		if (supports_clientArray()) {
			GL13.glClientActiveTexture(id);
			GLError.throwIfNecessary(this, "glClientActiveTexture");
			activeClient = this;
		} else {
			throw new IllegalStateException("This texture unit can not be made active client texture");
		}
	}
	
	public boolean is_active_clientArray() {
		return activeClient == this;
	}
	
}