package de.starzi.graphics.textures;

import org.lwjgl.opengl.GL11;

import de.starzi.graphics.opengl.GLEnum;

/**
 * The texture magnification function is used whenever the level-of-detail function used when 
 * sampling from the texture determines that the texture should be magified.
 * 
 * @author Nic Starzi
 * @date 29.12.2013
 *
 */
public enum MagFilter implements GLEnum {
	/**
	 * Returns the value of the texture element that is nearest (in Manhattan distance) to the specified texture coordinates.
	 * GL_NEAREST is generally faster than GL_LINEAR, but it can produce textured images with sharper edges because the transition between texture elements is not as smooth.
	 */
	NEAREST	(GL11.GL_NEAREST),
	
	/**
	 * Returns the weighted average of the texture elements that are closest to the specified texture coordinates. 
	 * These can include items wrapped or repeated from other parts of a texture, depending on the values of GL_TEXTURE_WRAP_S and GL_TEXTURE_WRAP_T, and on the exact mapping.
	 */
	LINEAR	(GL11.GL_LINEAR);
	
	private final int glEnum;
	
	private MagFilter(int glEnum) {
		this.glEnum = glEnum;
	}
	
	public int get_glEnum() {
		return glEnum;
	}
}