package de.starzi.graphics.textures;

import org.lwjgl.opengl.GL11;
import org.lwjgl.opengl.GL12;
import org.lwjgl.opengl.GL13;
import org.lwjgl.opengl.GL14;

import de.starzi.graphics.opengl.GLEnum;

/**
 * Defines how texels are fetched from a texture when the texture coordinate is outside of the textures area.
 * 
 * @author Nic Starzi
 * @date 29.12.2013
 *
 */
public enum Wrap implements GLEnum {
	
	/**
	 * Causes the integer part of the coordinate s to be ignored; 
	 * the GL uses only the fractional part, thereby creating a repeating pattern.
	 * 
	 * Supported since GL1.1
	 */
	REPEAT					(GL11.GL_REPEAT),
	
	/**
	 * Causes the coordinate s to be set to the fractional part of the texture coordinate if the integer part of s is even; 
	 * if the integer part of s is odd, then the s texture coordinate is set to 1 - frac(s), where frac(s) represents the fractional part of s.
	 * 
	 * Supported since GL1.4
	 */
	MIRRORED_REPEAT			(GL14.GL_MIRRORED_REPEAT),
	
	/**
	 * Causes the the coordinate s to be repeated as for MIRRORED_REPEAT for one repetition of the texture, at which point the coordinate will be clamped as in CLAMP_TO_EDGE.
	 * 
	 * Supported since GL1.1
	 */
	MIRROR_CLAMP_TO_EDGE	(GL11.GL_REPEAT),
	
	/**
	 * Causes coordinate s to be clamped to the range [ 1 / 2*N, 1 - 1 / 2*N], where N is the size of the texture in the direction of clamping.
	 * 
	 * Supported since GL1.2
	 */
	CLAMP_TO_EDGE			(GL12.GL_CLAMP_TO_EDGE),
	
	/**
	 * Evaluates coordinate s in a similar manner to CLAMP_TO_EDGE. 
	 * However, in cases where clamping would have occurred in CLAMP_TO_EDGE mode, the fetched texel data is substituted with the values specified by the textures border color.
	 * 
	 * Supported since GL1.3
	 */
	CLAMP_TO_BORDER			(GL13.GL_CLAMP_TO_BORDER);
	
	private final int glEnum;
	
	private Wrap(int glEnum) {
		this.glEnum = glEnum;
	}
	
	public int get_glEnum() {
		return glEnum;
	}
	
}